@@ -1,4 +1,6 @@
-from restapi_logging_handler import RestApiHandler
+from __future__ import absolute_import
+
+from restapi_logging_handler.restapi_logging_handler import RestApiHandler
 
 
 class LogglyHandler(RestApiHandler):
